@@ -96,7 +96,6 @@ setMethod("dbCreate", "ANY",
                   type <- filehashOption()$defaultType
 
               dbStartup(db, type, "create")
-              TRUE
           })
           
 setGeneric("dbInit", function(db, ...) standardGeneric("dbInit"))
@@ -228,6 +227,10 @@ setGeneric("dbDelete", function(db, key, ...) standardGeneric("dbDelete"))
 setGeneric("dbReorganize", function(db, ...) standardGeneric("dbReorganize"))
 setGeneric("dbUnlink", function(db, ...) standardGeneric("dbUnlink"))
 
+## Other
+setOldClass(c("file", "connection"))
+setGeneric("lockFile", function(db, ...) standardGeneric("lockFile"))
+
 ######################################################################
 ## Extractor/replacement
 
